@@ -4,23 +4,33 @@ use warnings;
 
 package Art::World {
 
-  our $VERSION = '0.19_02';
+  our $VERSION = '0.19_03';
 
   use Zydeco
     authority => 'cpan:SMONFF',
     # Predeclaration of types avoid use of quotes in args types declarations or
     # signatures. See https://codeberg.org/smonff/art-world/issues/37
-    declare => [
-      'Agent',
-      'Artwork',
-      'Collector',
-      'Event',
-      'Idea',
-      'Place',
-      'Theory',
-     ],
+     declare => [ qw(
+       Agent
+       Artwork
+       Collective
+       Collector
+       Coinvestor
+       Curator
+       Event
+       Idea
+       Place
+       Theory
+      )],
     version   => $VERSION;
 
+  # Workaround for types pre-declaration issue with Type::Tiny v2
+  # See https://github.com/tobyink/p5-zydeco/issues/15
+  BEGIN {
+    package Art::World::Types;
+    use Type::Library -base;
+  };
+
   use feature qw( postderef );
   no warnings qw( experimental::postderef );
   use Carp qw( carp cluck );
@@ -32,7 +42,7 @@ package Art::World {
 
   role Abstraction {
     has discourse ( type => Str );
-    has idea! ( type => Str, is => rw,  trigger => true );
+    has idea! ( type => Str, is => rw, trigger => true );
     # BUG if use "imagination" it will always be undef, because it comes alphabetically after "idea" :-/
     has _imagination ( type => ArrayRef[ Str ] ) = [];
     has process ( type => ArrayRef );
@@ -44,7 +54,6 @@ package Art::World {
     }
     method insert_to_file {}
     # etc.
-    use DDP;
     method _trigger_idea {
       push $self->_imagination->@*, $self->idea;
     }
@@ -73,7 +82,7 @@ package Art::World {
       clearer => true,
       writer  => 'set_owner',
       trigger => sub { shift->status('sold') },
-      type    => ArrayRef[ Agent ]) = $self->creator;
+      type    => ArrayRef[ Agent ] ) = $self->creator;
     has value  ( is   => rw );
     has status (
       is              => rw,
@@ -389,7 +398,7 @@ package Art::World {
           # increase it's own reputation
           my @all_the_other = grep { $_->id != $highest_influence_manager->id } $people->@*;
           for my $agent ( @all_the_other ) {
-            # The influence() methode is only a way of bumping_fame() with a special bumper
+            # The influence() method is only a way of bumping_fame() with a special bumper
             $agent->bump_fame( $highest_influence_manager->influence( $agent->reputation ));
           }
         }
@@ -430,7 +439,7 @@ package Art::World {
 
       class Collector with Active, Buyer, Market {
         has collection (
-          type    => ArrayRef[ Artwork, 0 ],
+          type    => ArrayRef[ Artwork ],
           default => sub { [] },
           is      => rw, );
         class Coinvestor with Collective {
@@ -479,7 +488,11 @@ package Art::World {
       # Same as Agent->reputation
       has aura( is => rw, type => PositiveOrZeroNum ) = 0;
 
-      class Article
+      class Article {
+        has author(
+          is   => ro,
+          type => Agent );
+      };
 
       class Artwork with Showable, Collectionable  {
         has material;
@@ -797,7 +810,8 @@ words, an C<INI> file can be provided.
 
 =head2 Article
 
-Something in a C<Magazine> of C<Website> about C<Art>, C<Exhibitions>, etc.
+Something in a C<Magazine> of C<Website> about C<Art>, C<Exhibitions>, etc.,
+usually written by a critic.
 
 =head2 Artist
 
@@ -1011,7 +1025,7 @@ This project was made possible by the greatness of the L<Zydeco|https://zydeco.t
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2006-2021 Sebastien Feugère
+Copyright 2006-2023 Sebastien Feugère
 
 This library is free software; you can redistribute it and/or modify it under
 the Artistic License 2.0.
